@@ -34,6 +34,37 @@ func (f *Format) Run() (err error) {
 	// set log level and other options
 	f.configureLogging()
 
+	// ci mode
+	if f.Ci {
+		f.NoCache = true
+		f.FailOnChange = true
+
+		// ensure INFO level
+		if f.Verbosity < 1 {
+			f.Verbosity = 1
+		}
+		// reconfigure logging
+		f.configureLogging()
+
+		log.Info("ci mode enabled")
+
+		startAfter := time.Now().
+			// truncate to second precision
+			Truncate(time.Second).
+			// add one second
+			Add(1 * time.Second).
+			// a little extra to ensure we don't start until the next second
+			Add(10 * time.Millisecond)
+
+		log.Debugf("waiting until %v before continuing", startAfter)
+
+		// Wait until we tick over into the next second before processing to ensure our EPOCH level modtime comparisons
+		// for change detection are accurate.
+		// This can fail in CI between checkout and running treefmt if everything happens too quickly.
+		// For humans, the second level precision should not be a problem as they are unlikely to run treefmt in sub-second succession.
+		<-time.After(time.Until(startAfter))
+	}
+
 	// cpu profiling
 	if f.CpuProfile != "" {
 		cpuProfile, err := os.Create(f.CpuProfile)
@@ -66,7 +97,7 @@ func (f *Format) Run() (err error) {
 		if err != nil {
 			return err
 		}
-		f.ConfigFile, _, err = findUp(pwd, "treefmt.toml")
+		f.ConfigFile, _, err = findUp(pwd, "treefmt.toml", ".treefmt.toml")
 		if err != nil {
 			return err
 		}
@@ -237,12 +268,9 @@ func (f *Format) walkFilesystem(ctx context.Context) func() error {
 				case <-ctx.Done():
 					return ctx.Err()
 				default:
-					// ignore symlinks and directories
-					if !(file.Info.IsDir() || file.Info.Mode()&os.ModeSymlink == os.ModeSymlink) {
-						stats.Add(stats.Traversed, 1)
-						stats.Add(stats.Emitted, 1)
-						f.filesCh <- file
-					}
+					stats.Add(stats.Traversed, 1)
+					stats.Add(stats.Emitted, 1)
+					f.filesCh <- file
 					return nil
 				}
 			})
@@ -499,14 +527,16 @@ func (f *Format) updateCache(ctx context.Context) func() error {
 	}
 }
 
-func findUp(searchDir string, fileName string) (path string, dir string, err error) {
+func findUp(searchDir string, fileNames ...string) (path string, dir string, err error) {
 	for _, dir := range eachDir(searchDir) {
-		path := filepath.Join(dir, fileName)
-		if fileExists(path) {
-			return path, dir, nil
+		for _, f := range fileNames {
+			path := filepath.Join(dir, f)
+			if fileExists(path) {
+				return path, dir, nil
+			}
 		}
 	}
-	return "", "", fmt.Errorf("could not find %s in %s", fileName, searchDir)
+	return "", "", fmt.Errorf("could not find %s in %s", fileNames, searchDir)
 }
 
 func eachDir(path string) (paths []string) {
